.. _contributing:

**********************
Contributing to pandas
**********************

See the following links:

- `The developer pages on the website
  <http://pandas.pydata.org/developers.html>`_
- `Guidelines on bug reports and pull requests
  <https://github.com/pydata/pandas/blob/master/CONTRIBUTING.md>`_
- `Some extra tips on using git
  <https://github.com/pydata/pandas/wiki/Using-Git>`_

.. include:: ../README.rst
